@@ -4,6 +4,7 @@ import (
 	"fmt"
 	"os"
 	"path/filepath"
+	"slices"
 	"strings"
 
 	"github.com/atotto/clipboard"
@@ -13,19 +14,19 @@ import (
 
 func CopyToClipboard(message string) (err error) {
 	if err = clipboard.WriteAll(message); err != nil {
-		err = fmt.Errorf("%s", fmt.Sprintf(i18n.T("could_not_copy_to_clipboard"), err))
+		err = fmt.Errorf(i18n.T("could_not_copy_to_clipboard"), err)
 	}
 	return
 }
 
 func CreateOutputFile(message string, fileName string) (err error) {
 	if _, err = os.Stat(fileName); err == nil {
-		err = fmt.Errorf("%s", fmt.Sprintf(i18n.T("file_already_exists_not_overwriting"), fileName))
+		err = fmt.Errorf(i18n.T("file_already_exists_not_overwriting"), fileName)
 		return
 	}
 	var file *os.File
 	if file, err = os.Create(fileName); err != nil {
-		err = fmt.Errorf("%s", fmt.Sprintf(i18n.T("error_creating_file"), err))
+		err = fmt.Errorf(i18n.T("error_creating_file"), err)
 		return
 	}
 	defer file.Close()
@@ -33,7 +34,7 @@ func CreateOutputFile(message string, fileName string) (err error) {
 		message += "\n"
 	}
 	if _, err = file.WriteString(message); err != nil {
-		err = fmt.Errorf("%s", fmt.Sprintf(i18n.T("error_writing_to_file"), err))
+		err = fmt.Errorf(i18n.T("error_writing_to_file"), err)
 	} else {
 		debuglog.Log("\n\n[Output also written to %s]\n", fileName)
 	}
@@ -50,13 +51,13 @@ func CreateAudioOutputFile(audioData []byte, fileName string) (err error) {
 	// File existence check is now done in the CLI layer before TTS generation
 	var file *os.File
 	if file, err = os.Create(fileName); err != nil {
-		err = fmt.Errorf("%s", fmt.Sprintf(i18n.T("error_creating_audio_file"), err))
+		err = fmt.Errorf(i18n.T("error_creating_audio_file"), err)
 		return
 	}
 	defer file.Close()
 
 	if _, err = file.Write(audioData); err != nil {
-		err = fmt.Errorf("%s", fmt.Sprintf(i18n.T("error_writing_audio_data"), err))
+		err = fmt.Errorf(i18n.T("error_writing_audio_data"), err)
 	}
 	// No redundant output message here - the CLI layer handles success messaging
 	return
@@ -66,10 +67,5 @@ func CreateAudioOutputFile(audioData []byte, fileName string) (err error) {
 func IsAudioFormat(fileName string) bool {
 	ext := strings.ToLower(filepath.Ext(fileName))
 	audioExts := []string{".wav", ".mp3", ".m4a", ".aac", ".ogg", ".flac"}
-	for _, audioExt := range audioExts {
-		if ext == audioExt {
-			return true
-		}
-	}
-	return false
+	return slices.Contains(audioExts, ext)
 }
