@@ -3,7 +3,6 @@ package anthropic
 import (
 	"context"
 	"fmt"
-	"net/http"
 	neturl "net/url"
 	"os"
 	"path"
@@ -14,9 +13,9 @@ import (
 	"github.com/anthropics/anthropic-sdk-go/option"
 	"github.com/danielmiessler/fabric/internal/chat"
 	"github.com/danielmiessler/fabric/internal/domain"
+	"github.com/danielmiessler/fabric/internal/i18n"
 	debuglog "github.com/danielmiessler/fabric/internal/log"
 	"github.com/danielmiessler/fabric/internal/plugins"
-	"github.com/danielmiessler/fabric/internal/util"
 )
 
 const defaultBaseUrl = "https://api.anthropic.com/"
@@ -25,8 +24,6 @@ const webSearchToolName = "web_search"
 const webSearchToolType = "web_search_20250305"
 const sourcesHeader = "## Sources"
 
-const authTokenIdentifier = "claude"
-
 func NewClient() (ret *Client) {
 	vendorName := "Anthropic"
 	ret = &Client{}
@@ -35,64 +32,64 @@ func NewClient() (ret *Client) {
 
 	ret.ApiBaseURL = ret.AddSetupQuestion("API Base URL", false)
 	ret.ApiBaseURL.Value = defaultBaseUrl
-	ret.UseOAuth = ret.AddSetupQuestionBool("Use OAuth login", false)
 	ret.ApiKey = ret.PluginBase.AddSetupQuestion("API key", false)
 
 	ret.maxTokens = 4096
 	ret.defaultRequiredUserMessage = "Hi"
 	ret.models = []string{
-		string(anthropic.ModelClaude3_7SonnetLatest), string(anthropic.ModelClaude3_7Sonnet20250219),
-		string(anthropic.ModelClaude3_5HaikuLatest), string(anthropic.ModelClaude3_5Haiku20241022),
-		string(anthropic.ModelClaude3OpusLatest), string(anthropic.ModelClaude_3_Opus_20240229),
-		string(anthropic.ModelClaude_3_Haiku_20240307),
-		string(anthropic.ModelClaudeOpus4_20250514), string(anthropic.ModelClaudeSonnet4_20250514),
-		string(anthropic.ModelClaudeOpus4_1_20250805),
-		string(anthropic.ModelClaudeSonnet4_5),
-		string(anthropic.ModelClaudeSonnet4_5_20250929),
+		// The following are the current supported models
+		string(anthropic.ModelClaudeSonnet4_6),
+		string(anthropic.ModelClaudeOpus4_6),
 		string(anthropic.ModelClaudeOpus4_5_20251101),
 		string(anthropic.ModelClaudeOpus4_5),
 		string(anthropic.ModelClaudeHaiku4_5),
 		string(anthropic.ModelClaudeHaiku4_5_20251001),
+		string(anthropic.ModelClaudeSonnet4_20250514),
+		string(anthropic.ModelClaudeSonnet4_0),
+		string(anthropic.ModelClaude4Sonnet20250514),
+		string(anthropic.ModelClaudeSonnet4_5),
+		string(anthropic.ModelClaudeSonnet4_5_20250929),
+		string(anthropic.ModelClaudeOpus4_0),
+		string(anthropic.ModelClaudeOpus4_20250514),
+		string(anthropic.ModelClaude4Opus20250514),
+		string(anthropic.ModelClaudeOpus4_1_20250805),
 	}
 
 	ret.modelBetas = map[string][]string{
-		string(anthropic.ModelClaudeSonnet4_20250514):   {"context-1m-2025-08-07"},
+		// See https://platform.claude.com/docs/en/build-with-claude/context-windows#1-m-token-context-window
+		// Claude Opus 4.6, Sonnet 4.6, Sonnet 4.5, and Sonnet 4 support a 1-million token context window.
+
+		// This list can change over time as Anthropic updates their models and beta features, so we maintain it separately from the main model list
+		// for easier updates.
+
+		// Claude Sonnet 4 variants (1M context support)
+		string(anthropic.ModelClaudeSonnet4_20250514): {"context-1m-2025-08-07"},
+		string(anthropic.ModelClaudeSonnet4_0):        {"context-1m-2025-08-07"},
+		string(anthropic.ModelClaude4Sonnet20250514):  {"context-1m-2025-08-07"},
+
+		// Claude Sonnet 4.5 variants (1M context support)
 		string(anthropic.ModelClaudeSonnet4_5):          {"context-1m-2025-08-07"},
 		string(anthropic.ModelClaudeSonnet4_5_20250929): {"context-1m-2025-08-07"},
+
+		// Claude Sonnet 4.6 (1M context support)
+		string(anthropic.ModelClaudeSonnet4_6): {"context-1m-2025-08-07"},
+
+		// Claude Opus 4.5 and 4.6 variants (1M context support)
+		string(anthropic.ModelClaudeOpus4_5):          {"context-1m-2025-08-07"},
+		string(anthropic.ModelClaudeOpus4_6):          {"context-1m-2025-08-07"},
+		string(anthropic.ModelClaudeOpus4_5_20251101): {"context-1m-2025-08-07"},
 	}
 
 	return
 }
 
-// IsConfigured returns true if either the API key or OAuth is configured
+// IsConfigured returns true if the API key is configured
 func (an *Client) IsConfigured() bool {
 	// Check if API key is configured
 	if an.ApiKey.Value != "" {
 		return true
 	}
 
-	// Check if OAuth is enabled and has a valid token
-	if plugins.ParseBoolElseFalse(an.UseOAuth.Value) {
-		storage, err := util.NewOAuthStorage()
-		if err != nil {
-			return false
-		}
-
-		// If no valid token exists, automatically run OAuth flow
-		if !storage.HasValidToken(authTokenIdentifier, 5) {
-			fmt.Println("OAuth enabled but no valid token found. Starting authentication...")
-			_, err := RunOAuthFlow(authTokenIdentifier)
-			if err != nil {
-				fmt.Printf("OAuth authentication failed: %v\n", err)
-				return false
-			}
-			// After successful OAuth flow, check again
-			return storage.HasValidToken(authTokenIdentifier, 5)
-		}
-
-		return true
-	}
-
 	return false
 }
 
@@ -100,7 +97,6 @@ type Client struct {
 	*plugins.PluginBase
 	ApiBaseURL *plugins.SetupQuestion
 	ApiKey     *plugins.SetupQuestion
-	UseOAuth   *plugins.SetupQuestion
 
 	maxTokens                  int
 	defaultRequiredUserMessage string
@@ -115,21 +111,6 @@ func (an *Client) Setup() (err error) {
 		return
 	}
 
-	if plugins.ParseBoolElseFalse(an.UseOAuth.Value) {
-		// Check if we have a valid stored token
-		storage, err := util.NewOAuthStorage()
-		if err != nil {
-			return err
-		}
-
-		if !storage.HasValidToken(authTokenIdentifier, 5) {
-			// No valid token, run OAuth flow
-			if _, err = RunOAuthFlow(authTokenIdentifier); err != nil {
-				return err
-			}
-		}
-	}
-
 	err = an.configure()
 	return
 }
@@ -141,17 +122,7 @@ func (an *Client) configure() (err error) {
 		opts = append(opts, option.WithBaseURL(an.ApiBaseURL.Value))
 	}
 
-	if plugins.ParseBoolElseFalse(an.UseOAuth.Value) {
-		// For OAuth, use Bearer token with custom headers
-		// Create custom HTTP client that adds OAuth Bearer token and beta header
-		baseTransport := &http.Transport{}
-		httpClient := &http.Client{
-			Transport: NewOAuthTransport(an, baseTransport),
-		}
-		opts = append(opts, option.WithHTTPClient(httpClient))
-	} else {
-		opts = append(opts, option.WithAPIKey(an.ApiKey.Value))
-	}
+	opts = append(opts, option.WithAPIKey(an.ApiKey.Value))
 
 	an.client = anthropic.NewClient(opts...)
 	return
@@ -239,7 +210,7 @@ func (an *Client) SendStream(
 	}
 
 	if stream.Err() != nil {
-		fmt.Fprintf(os.Stderr, "Messages stream error: %v\n", stream.Err())
+		fmt.Fprintf(os.Stderr, i18n.T("anthropic_stream_error"), stream.Err())
 	}
 	close(channel)
 	return
@@ -264,17 +235,6 @@ func (an *Client) buildMessageParams(msgs []anthropic.MessageParam, opts *domain
 		params.Temperature = anthropic.Opt(opts.Temperature)
 	}
 
-	// Add Claude Code spoofing system message for OAuth authentication
-	if plugins.ParseBoolElseFalse(an.UseOAuth.Value) {
-		params.System = []anthropic.TextBlockParam{
-			{
-				Type: "text",
-				Text: "You are Claude Code, Anthropic's official CLI for Claude.",
-			},
-		}
-
-	}
-
 	if opts.Search {
 		// Build the web-search tool definition:
 		webTool := anthropic.WebSearchTool20250305Param{
@@ -588,7 +548,3 @@ func isPDFURL(url string) bool {
 	}
 	return strings.EqualFold(path.Ext(parsedURL.Path), ".pdf")
 }
-
-func (an *Client) NeedsRawMode(modelName string) bool {
-	return false
-}
