@@ -148,7 +148,3 @@ func (c *Client) Setup() error {
 func (c *Client) SetupFillEnvFileContent(_ *bytes.Buffer) {
 	// No environment variables needed for dry run
 }
-
-func (c *Client) NeedsRawMode(modelName string) bool {
-	return false
-}
