@@ -3,6 +3,7 @@ package ollama
 import (
 	"context"
 	"encoding/base64"
+	"errors"
 	"fmt"
 	"io"
 	"net/http"
@@ -13,6 +14,7 @@ import (
 
 	"github.com/danielmiessler/fabric/internal/chat"
 	"github.com/danielmiessler/fabric/internal/domain"
+	"github.com/danielmiessler/fabric/internal/i18n"
 	debuglog "github.com/danielmiessler/fabric/internal/log"
 	"github.com/danielmiessler/fabric/internal/plugins"
 	ollamaapi "github.com/ollama/ollama/api"
@@ -27,12 +29,12 @@ func NewClient() (ret *Client) {
 	ret.PluginBase = plugins.NewVendorPluginBase(vendorName, ret.configure)
 
 	ret.ApiUrl = ret.AddSetupQuestionCustom("API URL", true,
-		"Enter your Ollama URL (as a reminder, it is usually http://localhost:11434')")
+		fmt.Sprintf(i18n.T("lmstudio_api_url_question"), vendorName, defaultBaseUrl))
 	ret.ApiUrl.Value = defaultBaseUrl
 	ret.ApiKey = ret.PluginBase.AddSetupQuestion("API key", false)
 	ret.ApiKey.Value = ""
 	ret.ApiHttpTimeout = ret.AddSetupQuestionCustom("HTTP Timeout", true,
-		"Specify HTTP timeout duration for Ollama requests (e.g. 30s, 5m, 1h)")
+		i18n.T("ollama_http_timeout_question"))
 	ret.ApiHttpTimeout.Value = "20m"
 
 	return
@@ -67,7 +69,7 @@ func (o *Client) IsConfigured() bool {
 
 func (o *Client) configure() (err error) {
 	if o.apiUrl, err = url.Parse(o.ApiUrl.Value); err != nil {
-		fmt.Printf("cannot parse URL: %s: %v\n", o.ApiUrl.Value, err)
+		fmt.Printf("%s\n", fmt.Sprintf(i18n.T("ollama_cannot_parse_url"), o.ApiUrl.Value, err))
 		return
 	}
 
@@ -78,7 +80,7 @@ func (o *Client) configure() (err error) {
 		if err == nil && o.ApiHttpTimeout.Value != "" {
 			timeout = parsed
 		} else if o.ApiHttpTimeout.Value != "" {
-			fmt.Printf("Invalid HTTP timeout format (%q), using default (20m): %v\n", o.ApiHttpTimeout.Value, err)
+			fmt.Printf("%s\n", fmt.Sprintf(i18n.T("ollama_invalid_http_timeout_using_default"), o.ApiHttpTimeout.Value, err))
 		}
 	}
 
@@ -152,7 +154,7 @@ func (o *Client) Send(ctx context.Context, msgs []*chat.ChatCompletionMessage, o
 	}
 
 	if err = o.client.Chat(ctx, &req, respFunc); err != nil {
-		debuglog.Debug(debuglog.Basic, "Ollama chat request failed: %v\n", err)
+		debuglog.Debug(debuglog.Basic, "%s\n", fmt.Sprintf(i18n.T("ollama_chat_request_failed"), err))
 	}
 	return
 }
@@ -225,11 +227,11 @@ func (o *Client) loadImageBytes(ctx context.Context, imageURL string) (ret []byt
 	if strings.HasPrefix(imageURL, "data:") {
 		parts := strings.SplitN(imageURL, ",", 2)
 		if len(parts) != 2 {
-			err = fmt.Errorf("invalid data URL format")
+			err = errors.New(i18n.T("ollama_invalid_data_url_format"))
 			return
 		}
 		if ret, err = base64.StdEncoding.DecodeString(parts[1]); err != nil {
-			err = fmt.Errorf("failed to decode data URL: %w", err)
+			err = fmt.Errorf("%s", fmt.Sprintf(i18n.T("ollama_failed_decode_data_url"), err))
 		}
 		return
 	}
@@ -247,7 +249,7 @@ func (o *Client) loadImageBytes(ctx context.Context, imageURL string) (ret []byt
 	defer resp.Body.Close()
 
 	if resp.StatusCode >= http.StatusBadRequest {
-		err = fmt.Errorf("failed to fetch image %s: %s", imageURL, resp.Status)
+		err = fmt.Errorf("%s", fmt.Sprintf(i18n.T("ollama_failed_fetch_image"), imageURL, resp.Status))
 		return
 	}
 
