@@ -3,6 +3,7 @@ package openai
 import (
 	"bytes"
 	"context"
+	"errors"
 	"fmt"
 	"os"
 	"os/exec"
@@ -12,6 +13,7 @@ import (
 	"strings"
 	"sync"
 
+	"github.com/danielmiessler/fabric/internal/i18n"
 	debuglog "github.com/danielmiessler/fabric/internal/log"
 
 	openai "github.com/openai/openai-go"
@@ -53,12 +55,12 @@ func (o *Client) TranscribeFile(ctx context.Context, filePath, model string, spl
 	}
 
 	if !slices.Contains(AllowedTranscriptionModels, model) {
-		return "", fmt.Errorf("model '%s' is not supported for transcription", model)
+		return "", fmt.Errorf("%s", fmt.Sprintf(i18n.T("openai_audio_model_not_supported_for_transcription"), model))
 	}
 
 	ext := strings.ToLower(filepath.Ext(filePath))
 	if _, ok := allowedAudioExtensions[ext]; !ok {
-		return "", fmt.Errorf("unsupported audio format '%s'", ext)
+		return "", fmt.Errorf("%s", fmt.Sprintf(i18n.T("openai_audio_unsupported_audio_format"), ext))
 	}
 
 	info, err := os.Stat(filePath)
@@ -70,9 +72,9 @@ func (o *Client) TranscribeFile(ctx context.Context, filePath, model string, spl
 	var cleanup func()
 	if info.Size() > MaxAudioFileSize {
 		if !split {
-			return "", fmt.Errorf("file %s exceeds 25MB limit; use --split-media-file to enable automatic splitting", filePath)
+			return "", fmt.Errorf("%s", fmt.Sprintf(i18n.T("openai_audio_file_exceeds_limit_enable_split"), filePath))
 		}
-		debuglog.Log("File %s is larger than the size limit... breaking it up into chunks...\n", filePath)
+		debuglog.Log("%s\n", fmt.Sprintf(i18n.T("openai_audio_file_exceeds_limit_splitting"), filePath))
 		if files, cleanup, err = splitAudioFile(filePath, ext, MaxAudioFileSize); err != nil {
 			return "", err
 		}
@@ -88,7 +90,7 @@ func (o *Client) TranscribeFile(ctx context.Context, filePath, model string, spl
 		wg.Add(1)
 		go func(index int, filePath string) {
 			defer wg.Done()
-			debuglog.Log("Using model %s to transcribe part %d (file name: %s)...\n", model, index+1, filePath)
+			debuglog.Log("%s\n", fmt.Sprintf(i18n.T("openai_audio_using_model_to_transcribe_part"), model, index+1, filePath))
 
 			chunk, openErr := os.Open(filePath)
 			if openErr != nil {
@@ -140,7 +142,7 @@ func (o *Client) TranscribeFile(ctx context.Context, filePath, model string, spl
 // It returns the list of chunk file paths and a cleanup function.
 func splitAudioFile(src, ext string, maxSize int64) (files []string, cleanup func(), err error) {
 	if _, err = exec.LookPath("ffmpeg"); err != nil {
-		return nil, nil, fmt.Errorf("ffmpeg not found: please install it")
+		return nil, nil, errors.New(i18n.T("openai_audio_ffmpeg_not_found_install"))
 	}
 
 	var dir string
@@ -152,12 +154,12 @@ func splitAudioFile(src, ext string, maxSize int64) (files []string, cleanup fun
 	segmentTime := 600 // start with 10 minutes
 	for {
 		pattern := filepath.Join(dir, "chunk-%03d"+ext)
-		debuglog.Log("Running ffmpeg to split audio into %d-second chunks...\n", segmentTime)
+		debuglog.Log("%s\n", fmt.Sprintf(i18n.T("openai_audio_running_ffmpeg_split_chunks"), segmentTime))
 		cmd := exec.Command("ffmpeg", "-y", "-i", src, "-f", "segment", "-segment_time", fmt.Sprintf("%d", segmentTime), "-c", "copy", pattern)
 		var stderr bytes.Buffer
 		cmd.Stderr = &stderr
 		if err = cmd.Run(); err != nil {
-			return nil, cleanup, fmt.Errorf("ffmpeg failed: %v: %s", err, stderr.String())
+			return nil, cleanup, fmt.Errorf("%s", fmt.Sprintf(i18n.T("openai_audio_ffmpeg_failed"), err, stderr.String()))
 		}
 
 		if files, err = filepath.Glob(filepath.Join(dir, "chunk-*"+ext)); err != nil {
@@ -183,7 +185,7 @@ func splitAudioFile(src, ext string, maxSize int64) (files []string, cleanup fun
 			_ = os.Remove(f)
 		}
 		if segmentTime <= 1 {
-			return nil, cleanup, fmt.Errorf("unable to split file into acceptable size chunks")
+			return nil, cleanup, errors.New(i18n.T("openai_audio_unable_to_split_acceptable_size_chunks"))
 		}
 		segmentTime /= 2
 	}
