@@ -6,7 +6,7 @@ RESPONSE=$(curl "$OPENAI_API_BASE_URL/chat/completions" \
   -s -w "\n%{http_code}" \
   -H "Content-Type: application/json" \
   -H "Authorization: Bearer $OPENAI_API_KEY" \
-  -d "{\"model\":\"gpt-4o-mini\",\"messages\":[{\"role\":\"user\",\"content\":$INPUT}]}")
+  -d "{\"model\":\"gpt-5-mini\",\"messages\":[{\"role\":\"user\",\"content\":$INPUT}]}")
 
 HTTP_CODE=$(echo "$RESPONSE" | tail -n1)
 BODY=$(echo "$RESPONSE" | sed '$d')
