@@ -3,6 +3,7 @@ package template
 import (
 	"crypto/sha256"
 	"encoding/hex"
+	"errors"
 	"fmt"
 	"io"
 	"os"
@@ -10,6 +11,7 @@ import (
 	"strings"
 	"time"
 
+	"github.com/danielmiessler/fabric/internal/i18n"
 	debuglog "github.com/danielmiessler/fabric/internal/log"
 
 	"gopkg.in/yaml.v3"
@@ -88,7 +90,7 @@ func NewExtensionRegistry(configDir string) *ExtensionRegistry {
 	r.ensureConfigDir()
 
 	if err := r.loadRegistry(); err != nil {
-		debuglog.Log("Warning: could not load extension registry: %v\n", err)
+		debuglog.Log(i18n.T("extension_warning_load_registry"), err)
 	}
 
 	return r
@@ -105,44 +107,44 @@ func (r *ExtensionRegistry) Register(configPath string) error {
 	// Read and parse the extension definition to verify it
 	data, err := os.ReadFile(configPath)
 	if err != nil {
-		return fmt.Errorf("failed to read config file: %w", err)
+		return fmt.Errorf(i18n.T("extension_failed_read_config"), err)
 	}
 
 	var ext ExtensionDefinition
 	if err := yaml.Unmarshal(data, &ext); err != nil {
-		return fmt.Errorf("failed to parse config file: %w", err)
+		return fmt.Errorf(i18n.T("extension_failed_parse_config"), err)
 	}
 
 	// Validate extension name
 	if ext.Name == "" {
-		return fmt.Errorf("extension name cannot be empty")
+		return errors.New(i18n.T("extension_name_empty"))
 	}
 
 	if strings.Contains(ext.Name, " ") {
-		return fmt.Errorf("extension name '%s' contains spaces - names must not contain spaces", ext.Name)
+		return fmt.Errorf("%s", fmt.Sprintf(i18n.T("extension_name_contains_spaces"), ext.Name))
 	}
 
 	// Verify executable exists
 	if _, err := os.Stat(ext.Executable); err != nil {
-		return fmt.Errorf("executable not found: %w", err)
+		return fmt.Errorf(i18n.T("extension_executable_not_found"), err)
 	}
 
 	// Get absolute path to config
 	absPath, err := filepath.Abs(configPath)
 	if err != nil {
-		return fmt.Errorf("failed to get absolute path: %w", err)
+		return fmt.Errorf(i18n.T("extension_failed_get_absolute_path"), err)
 	}
 
 	// Calculate hashes
 	configHash := ComputeStringHash(string(data))
 	executableHash, err := ComputeHash(ext.Executable)
 	if err != nil {
-		return fmt.Errorf("failed to hash executable: %w", err)
+		return fmt.Errorf(i18n.T("extension_failed_hash_executable"), err)
 	}
 
 	// Validate full extension definition (ensures operations and cmd_template present)
 	if err := r.validateExtensionDefinition(&ext); err != nil {
-		return fmt.Errorf("invalid extension definition: %w", err)
+		return fmt.Errorf(i18n.T("extension_invalid_definition"), err)
 	}
 
 	// Store entry
@@ -158,29 +160,29 @@ func (r *ExtensionRegistry) Register(configPath string) error {
 func (r *ExtensionRegistry) validateExtensionDefinition(ext *ExtensionDefinition) error {
 	// Validate required fields
 	if ext.Name == "" {
-		return fmt.Errorf("extension name is required")
+		return errors.New(i18n.T("extension_name_required"))
 	}
 	if ext.Executable == "" {
-		return fmt.Errorf("executable path is required")
+		return errors.New(i18n.T("extension_executable_required"))
 	}
 	if ext.Type == "" {
-		return fmt.Errorf("extension type is required")
+		return errors.New(i18n.T("extension_type_required"))
 	}
 
 	// Validate timeout format
 	if ext.Timeout != "" {
 		if _, err := time.ParseDuration(ext.Timeout); err != nil {
-			return fmt.Errorf("invalid timeout format: %w", err)
+			return fmt.Errorf(i18n.T("extension_invalid_timeout_format"), err)
 		}
 	}
 
 	// Validate operations
 	if len(ext.Operations) == 0 {
-		return fmt.Errorf("at least one operation must be defined")
+		return errors.New(i18n.T("extension_operation_required"))
 	}
 	for name, op := range ext.Operations {
 		if op.CmdTemplate == "" {
-			return fmt.Errorf("command template is required for operation %s", name)
+			return fmt.Errorf("%s", fmt.Sprintf(i18n.T("extension_cmd_template_required"), name))
 		}
 	}
 
@@ -189,7 +191,7 @@ func (r *ExtensionRegistry) validateExtensionDefinition(ext *ExtensionDefinition
 
 func (r *ExtensionRegistry) Remove(name string) error {
 	if _, exists := r.registry.Extensions[name]; !exists {
-		return fmt.Errorf("extension %s not found", name)
+		return fmt.Errorf("%s", fmt.Sprintf(i18n.T("extension_not_found"), name))
 	}
 
 	delete(r.registry.Extensions, name)
@@ -201,35 +203,35 @@ func (r *ExtensionRegistry) Verify(name string) error {
 	// Get the registry entry
 	entry, exists := r.registry.Extensions[name]
 	if !exists {
-		return fmt.Errorf("extension %s not found", name)
+		return fmt.Errorf("%s", fmt.Sprintf(i18n.T("extension_not_found"), name))
 	}
 
 	// Load and parse the config file
 	data, err := os.ReadFile(entry.ConfigPath)
 	if err != nil {
-		return fmt.Errorf("failed to read config file: %w", err)
+		return fmt.Errorf(i18n.T("extension_failed_read_config"), err)
 	}
 
 	// Verify config hash
 	currentConfigHash := ComputeStringHash(string(data))
 	if currentConfigHash != entry.ConfigHash {
-		return fmt.Errorf("config file hash mismatch for %s", name)
+		return fmt.Errorf("%s", fmt.Sprintf(i18n.T("extension_config_hash_mismatch"), name))
 	}
 
 	// Parse to get executable path
 	var ext ExtensionDefinition
 	if err := yaml.Unmarshal(data, &ext); err != nil {
-		return fmt.Errorf("failed to parse config file: %w", err)
+		return fmt.Errorf(i18n.T("extension_failed_parse_config"), err)
 	}
 
 	// Verify executable hash
 	currentExecutableHash, err := ComputeHash(ext.Executable)
 	if err != nil {
-		return fmt.Errorf("failed to verify executable: %w", err)
+		return fmt.Errorf(i18n.T("extension_failed_verify_executable"), err)
 	}
 
 	if currentExecutableHash != entry.ExecutableHash {
-		return fmt.Errorf("executable hash mismatch for %s", name)
+		return fmt.Errorf("%s", fmt.Sprintf(i18n.T("extension_executable_hash_mismatch"), name))
 	}
 
 	return nil
@@ -238,35 +240,35 @@ func (r *ExtensionRegistry) Verify(name string) error {
 func (r *ExtensionRegistry) GetExtension(name string) (*ExtensionDefinition, error) {
 	entry, exists := r.registry.Extensions[name]
 	if !exists {
-		return nil, fmt.Errorf("extension %s not found", name)
+		return nil, fmt.Errorf("%s", fmt.Sprintf(i18n.T("extension_not_found"), name))
 	}
 
 	// Read current config file
 	data, err := os.ReadFile(entry.ConfigPath)
 	if err != nil {
-		return nil, fmt.Errorf("failed to read config file: %w", err)
+		return nil, fmt.Errorf(i18n.T("extension_failed_read_config"), err)
 	}
 
 	// Verify config hash
 	currentHash := ComputeStringHash(string(data))
 	if currentHash != entry.ConfigHash {
-		return nil, fmt.Errorf("config file hash mismatch for %s", name)
+		return nil, fmt.Errorf("%s", fmt.Sprintf(i18n.T("extension_config_hash_mismatch"), name))
 	}
 
 	// Parse config
 	var ext ExtensionDefinition
 	if err := yaml.Unmarshal(data, &ext); err != nil {
-		return nil, fmt.Errorf("failed to parse config file: %w", err)
+		return nil, fmt.Errorf(i18n.T("extension_failed_parse_config"), err)
 	}
 
 	// Verify executable hash
 	currentExecHash, err := ComputeHash(ext.Executable)
 	if err != nil {
-		return nil, fmt.Errorf("failed to verify executable: %w", err)
+		return nil, fmt.Errorf(i18n.T("extension_failed_verify_executable"), err)
 	}
 
 	if currentExecHash != entry.ExecutableHash {
-		return nil, fmt.Errorf("executable hash mismatch for %s", name)
+		return nil, fmt.Errorf("%s", fmt.Sprintf(i18n.T("extension_executable_hash_mismatch"), name))
 	}
 
 	return &ext, nil
@@ -307,7 +309,7 @@ func (r *ExtensionRegistry) calculateFileHash(path string) (string, error) {
 func (r *ExtensionRegistry) saveRegistry() error {
 	data, err := yaml.Marshal(r.registry)
 	if err != nil {
-		return fmt.Errorf("failed to marshal extension registry: %w", err)
+		return fmt.Errorf(i18n.T("extension_failed_marshal_registry"), err)
 	}
 
 	registryPath := filepath.Join(r.configDir, "extensions", "extensions.yaml")
@@ -321,12 +323,12 @@ func (r *ExtensionRegistry) loadRegistry() error {
 		if os.IsNotExist(err) {
 			return nil // New registry
 		}
-		return fmt.Errorf("failed to read extension registry: %w", err)
+		return fmt.Errorf(i18n.T("extension_failed_read_registry"), err)
 	}
 
 	// Need to unmarshal the data into our registry
 	if err := yaml.Unmarshal(data, &r.registry); err != nil {
-		return fmt.Errorf("failed to parse extension registry: %w", err)
+		return fmt.Errorf(i18n.T("extension_failed_parse_registry"), err)
 	}
 
 	return nil
