@@ -7,12 +7,14 @@ import (
 	"path/filepath"
 	"runtime"
 	"strings"
+
+	"github.com/danielmiessler/fabric/internal/i18n"
 )
 
 // GetAbsolutePath resolves a given path to its absolute form, handling ~, ./, ../, UNC paths, and symlinks.
 func GetAbsolutePath(path string) (string, error) {
 	if path == "" {
-		return "", errors.New("path is empty")
+		return "", errors.New(i18n.T("util_error_path_is_empty"))
 	}
 
 	// Handle UNC paths on Windows
@@ -24,7 +26,7 @@ func GetAbsolutePath(path string) (string, error) {
 	if strings.HasPrefix(path, "~") {
 		home, err := os.UserHomeDir()
 		if err != nil {
-			return "", errors.New("could not resolve home directory")
+			return "", errors.New(i18n.T("util_error_resolve_home_directory"))
 		}
 		path = filepath.Join(home, path[1:])
 	}
@@ -32,7 +34,7 @@ func GetAbsolutePath(path string) (string, error) {
 	// Convert to absolute path
 	absPath, err := filepath.Abs(path)
 	if err != nil {
-		return "", errors.New("could not get absolute path")
+		return "", errors.New(i18n.T("util_error_get_absolute_path"))
 	}
 
 	// Resolve symlinks, but allow non-existent paths
@@ -45,7 +47,7 @@ func GetAbsolutePath(path string) (string, error) {
 		return absPath, nil
 	}
 
-	return "", fmt.Errorf("could not resolve symlinks: %w", err)
+	return "", fmt.Errorf(i18n.T("util_error_resolve_symlinks"), err)
 }
 
 // Helper function to check if a symlink points to a directory
@@ -77,7 +79,7 @@ func IsSymlinkToDir(path string) bool {
 func GetDefaultConfigPath() (string, error) {
 	homeDir, err := os.UserHomeDir()
 	if err != nil {
-		return "", fmt.Errorf("could not determine user home directory: %w", err)
+		return "", fmt.Errorf(i18n.T("util_error_determine_home_directory"), err)
 	}
 
 	defaultConfigPath := filepath.Join(homeDir, ".config", "fabric", "config.yaml")
@@ -85,7 +87,7 @@ func GetDefaultConfigPath() (string, error) {
 		if os.IsNotExist(err) {
 			return "", nil // Return no error for non-existent config path
 		}
-		return "", fmt.Errorf("error accessing default config path: %w", err)
+		return "", fmt.Errorf(i18n.T("util_error_accessing_config_path"), err)
 	}
 	return defaultConfigPath, nil
 }
