@@ -86,7 +86,11 @@ export class ChatService {
 		}
 	}
 
-	private cleanPatternOutput(content: string): string {
+	/**
+	 * Clean up pattern output for display. Should only be called on complete/accumulated content,
+	 * never on individual streaming tokens (which have leading spaces as word separators).
+	 */
+	public cleanPatternOutput(content: string): string {
 		// Remove markdown fence if present
 		let cleaned = content.replace(/^```markdown\n/, "");
 		cleaned = cleaned.replace(/\n```$/, "");
@@ -99,6 +103,7 @@ export class ChatService {
 		cleaned = cleaned.replace(/^#\s+([A-Z]+)\s*$/gm, "$1");
 		cleaned = cleaned.trim();
 		cleaned = cleaned.replace(/\n{3,}/g, "\n\n");
+
 		return cleaned;
 	}
 
@@ -106,7 +111,6 @@ export class ChatService {
 		reader: ReadableStreamDefaultReader<Uint8Array>,
 	): ReadableStream<StreamResponse> {
 		let buffer = "";
-		const cleanPatternOutput = this.cleanPatternOutput.bind(this);
 		const language = get(languageStore);
 		const validator = new LanguageValidator(language);
 
@@ -114,7 +118,10 @@ export class ChatService {
 			const pattern = get(selectedPatternName);
 
 			if (pattern) {
-				response.content = cleanPatternOutput(response.content);
+				// Do NOT call cleanPatternOutput here - it runs on each streaming token
+				// and .trim() strips leading spaces that serve as word separators.
+				// Cleaning should be done on the final accumulated content at display time.
+
 				// Simplified format determination - always markdown unless mermaid
 				const isMermaid = [
 					"graph TD",
@@ -142,31 +149,42 @@ export class ChatService {
 						if (done) break;
 
 						buffer += new TextDecoder().decode(value);
-						const messages = buffer
-							.split("\n\n")
-							.filter((msg) => msg.startsWith("data: "));
+						const segments = buffer.split("\n\n");
+						// Last segment may be incomplete; keep it as buffer
+						buffer = segments.pop() || "";
+						for (const segment of segments) {
+							const trimmed = segment.trim();
+							if (!trimmed.startsWith("data: ")) continue;
+							try {
+								let response = JSON.parse(
+									trimmed.slice(6),
+								) as StreamResponse;
 
-						if (messages.length > 1) {
-							buffer = messages.pop() || "";
-							for (const msg of messages) {
-								try {
-									let response = JSON.parse(msg.slice(6)) as StreamResponse;
-									response = processResponse(response);
-									controller.enqueue(response);
-								} catch (parseError) {
-									console.error("Error parsing stream message:", parseError);
-								}
+								response = processResponse(response);
+								controller.enqueue(response);
+							} catch (parseError) {
+								console.error(
+									"Error parsing stream message:",
+									parseError,
+								);
 							}
 						}
 					}
 
-					if (buffer.startsWith("data: ")) {
+					// Process any remaining complete message in the buffer
+					const trimmed = buffer.trim();
+					if (trimmed.startsWith("data: ")) {
 						try {
-							let response = JSON.parse(buffer.slice(6)) as StreamResponse;
+							let response = JSON.parse(
+								trimmed.slice(6),
+							) as StreamResponse;
 							response = processResponse(response);
 							controller.enqueue(response);
 						} catch (parseError) {
-							console.error("Error parsing final message:", parseError);
+							console.error(
+								"Error parsing final message:",
+								parseError,
+							);
 						}
 					}
 				} catch (error) {
